pub struct DayPlan {
pub tasks: Vec<Task>,
/* private fields */
}Fields
tasks: Vec<Task>Implementations
Sourceimpl DayPlan
impl DayPlan
pub fn new(tasks: Vec<Task>) -> Self
pub fn active_index(&self) -> Option<usize>
pub fn add_task(&mut self, task: Task) -> usize
pub fn start(&mut self, index: usize)
pub fn pause_active(&mut self)
Sourcepub fn finish_at(&mut self, index: usize, today_ymd: u32)
pub fn finish_at(&mut self, index: usize, today_ymd: u32)
Mark the task at index as Done with the given date (YYYYMMDD).
- If it was the active task, clear active.
pub fn add_actual_to_active(&mut self, minutes: u16)
pub fn remaining_total_min(&self) -> u16
pub fn esd(&self, now_min: u16) -> u16
pub fn reorder_down(&mut self, index: usize) -> usize
pub fn reorder_up(&mut self, index: usize) -> usize
Sourcepub fn move_index(&mut self, from: usize, to_slot: usize) -> usize
pub fn move_index(&mut self, from: usize, to_slot: usize) -> usize
Move task from from index to logical position to (clamped to list bounds).
Returns the new index of the moved task. Adjusts active pointer accordingly.
pub fn adjust_estimate(&mut self, index: usize, delta_min: i16)
pub fn remove(&mut self, index: usize) -> Option<Task>